@@ -1,7 +1,7 @@
 import os
 from pymatgen.analysis.phase_diagram import PhaseDiagram
 import pytest
-from mp_api.routes.thermo import ThermoRester
+from mp_api.client.routes.thermo import ThermoRester
 
 import typing
 
@@ -42,7 +42,9 @@ custom_field_tests = {
 }  # type: dict
 
 
-@pytest.mark.skipif(os.environ.get("MP_API_KEY", None) is None, reason="No API key found.")
+@pytest.mark.skipif(
+    os.environ.get("MP_API_KEY", None) is None, reason="No API key found."
+)
 def test_client(rester):
     search_method = rester.search
 
@@ -63,7 +65,9 @@ def test_client(rester):
                         param: (-100, 100),
                         "chunk_size": 1,
                         "num_chunks": 1,
-                        "fields": [project_field if project_field is not None else param],
+                        "fields": [
+                            project_field if project_field is not None else param
+                        ],
                     }
                 elif param_type == typing.Tuple[float, float]:
                     project_field = alt_name_dict.get(param, None)
@@ -71,7 +75,9 @@ def test_client(rester):
                         param: (-100.12, 100.12),
                         "chunk_size": 1,
                         "num_chunks": 1,
-                        "fields": [project_field if project_field is not None else param],
+                        "fields": [
+                            project_field if project_field is not None else param
+                        ],
                     }
                 elif param_type is bool:
                     project_field = alt_name_dict.get(param, None)
@@ -79,7 +85,9 @@ def test_client(rester):
                         param: False,
                         "chunk_size": 1,
                         "num_chunks": 1,
-                        "fields": [project_field if project_field is not None else param],
+                        "fields": [
+                            project_field if project_field is not None else param
+                        ],
                     }
                 elif param in custom_field_tests:
                     project_field = alt_name_dict.get(param, None)
@@ -87,7 +95,9 @@ def test_client(rester):
                         param: custom_field_tests[param],
                         "chunk_size": 1,
                         "num_chunks": 1,
-                        "fields": [project_field if project_field is not None else param],
+                        "fields": [
+                            project_field if project_field is not None else param
+                        ],
                     }
 
                 doc = search_method(**q)[0].dict()
@@ -95,11 +105,16 @@ def test_client(rester):
                     if sub_field in doc:
                         doc = doc[sub_field]
 
-                assert doc[project_field if project_field is not None else param] is not None
+                assert (
+                    doc[project_field if project_field is not None else param]
+                    is not None
+                )
 
 
 @pytest.mark.xfail(reason="Monty decode issue with phase diagram")
 def test_get_phase_diagram_from_chemsys():
     # Test that a phase diagram is returned
 
-    assert isinstance(ThermoRester().get_phase_diagram_from_chemsys("Hf-Pm"), PhaseDiagram)
+    assert isinstance(
+        ThermoRester().get_phase_diagram_from_chemsys("Hf-Pm"), PhaseDiagram
+    )
